@@ -10,7 +10,7 @@ automake --add-missing --foreign --copy
 
 automake_version=`automake --version  |grep automake |sed 's/^[^0-9]*\([0-9.][0-9.]*\).*/\1/'`
 case "$automake_version" in
-  1.8*|1.9*) glib-gettextize -c -f ;;
+  1.8*|1.9*) cp -f mkinstalldirs.dist mkinstalldirs ;;
 esac
 
 autoconf
