@@ -21,6 +21,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include "kazehakase.h"
 #include "kz-actions-download.h"
 #include "kz-downloader-group.h"
 #include "gtk-utils.h"
@@ -37,6 +38,7 @@ kz_actions_download_open_save_dialog (GtkWindow *window,
 	GtkWidget *file_dialog;
 	const gchar *basename = NULL;
 	gchar *selected_filename = NULL;
+	gchar *default_folder_for_saving = NULL;
 	gint result;
 
 	if (!uri) return NULL;
@@ -53,6 +55,13 @@ kz_actions_download_open_save_dialog (GtkWindow *window,
 	/* set default filename created from uri */
 	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(file_dialog), basename);
 
+	default_folder_for_saving = KZ_CONF_GET_STR("Download",
+						    "default_folder_for_saving");
+
+        /* set the default folder for saving */
+	if(default_folder_for_saving)
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_dialog), default_folder_for_saving);
+
 	/* Display that dialog */
 	result = gtk_dialog_run(GTK_DIALOG(file_dialog));
 
@@ -68,6 +77,13 @@ kz_actions_download_open_save_dialog (GtkWindow *window,
 			if (!ret)
 				break;
 		}
+
+		if(default_folder_for_saving)
+			g_free(default_folder_for_saving);
+		default_folder_for_saving = g_path_get_dirname (selected_filename);
+
+		KZ_CONF_SET_STR("Download", "default_folder_for_saving", default_folder_for_saving);
+
 		/* FIXME! it's the hacky way! */
 		if (content)
 		{
@@ -84,6 +100,8 @@ kz_actions_download_open_save_dialog (GtkWindow *window,
 
 	if (selected_filename)
 		g_free(selected_filename);
+	if(default_folder_for_saving)
+		g_free(default_folder_for_saving);
 
 	return NULL;
 }
