@@ -994,6 +994,11 @@ act_tab_close_all_inactive_active (GtkAction *action, KzWindow *kz)
 	}
 }
 
+static void
+act_tab_close_all (GtkAction *action, KzWindow *kz)
+{
+	kz_window_close_all_tab(kz);
+}
 
 static void
 act_bookmark_in_new_tab (GtkAction *action, KzWindow *kz)
@@ -1943,7 +1948,7 @@ GtkActionEntry kz_actions[] =
   {"StockRecentCloseTabMenu", NULL, N_("Recent closed tabs"), NULL, NULL, NULL},
   {"StockClipMenu",           NULL, N_("Clip"),        NULL, NULL, NULL},
 
-  {"NewWindow", KZ_STOCK_NEW_WINDOW, N_("_New Window"), CTRL"N",  N_("Open a new windw"), G_CALLBACK(act_new_window)},
+  {"NewWindow", KZ_STOCK_NEW_WINDOW, N_("_New Window"), CTRL"N",  N_("Open a new window"), G_CALLBACK(act_new_window)},
   {"NewTab",    GTK_STOCK_NEW,       N_("New _Tab"),    CTRL"T",  N_("Open a new tab"), G_CALLBACK(act_new_tab)},
 
   {"FocusLocationEntry",        NULL, N_("Focus to location entry"),  NULL, N_("Move keyboard focus to location entry"), G_CALLBACK(act_focus_loc_ent)},
@@ -2025,6 +2030,7 @@ GtkActionEntry kz_actions[] =
   {"CloseAllBackwardTab", KZ_STOCK_CLOSE_BACKWARD, N_("Close all _backward tabs"), NULL, NULL, G_CALLBACK(act_tab_close_backward_all)},
   {"CloseAllForwardTab", KZ_STOCK_CLOSE_FORWARD, N_("Close all _forward tabs"),  NULL, NULL, G_CALLBACK(act_tab_close_forward_all)},
   {"CloseAllInactiveTabs", NULL, N_("Close all _inactive tabs"), NULL, NULL, G_CALLBACK(act_tab_close_all_inactive_active)},
+  {"CloseAllTabs", NULL, N_("Clos_e all tabs"), NULL, NULL, G_CALLBACK(act_tab_close_all)},
 
   {"OpenBookmarkInNewTab",      NULL, N_("Open the bookmark in new _tab"),   NULL,  NULL, G_CALLBACK(act_bookmark_in_new_tab)},
   {"OpenAllBookmarks",          NULL, N_("Open a_ll bookmarks"),             NULL,  NULL, G_CALLBACK(act_open_all_bookmarks)},
@@ -2050,7 +2056,7 @@ GtkActionEntry kz_actions[] =
   /* {"SwitchSession", NULL, N_("Switch current session ..."), NULL, NULL, G_CALLBACK(act_switch_session)}, */
   {"ShowPassword", NULL, N_("_Show Password Manager"), NULL,  NULL, G_CALLBACK(act_show_password_manager)},
   {"ShowCopyFormat", NULL, N_("_Show Copy Format"), NULL,  NULL, G_CALLBACK(act_show_copy_format)},
-  {"About",        NULL, N_("About Kazehakase"),       NULL,  N_("Display credits"), G_CALLBACK(act_about)},
+  {"About",        GTK_STOCK_ABOUT, N_("About Kazehakase"),       NULL,  N_("Display credits"), G_CALLBACK(act_about)},
   {"OpenKazehakaseWebsite",        NULL, N_("Open Kazehakase Website"),       NULL,  N_("Open Kazehakase website in new tab"), G_CALLBACK(act_open_kazehakase_website)},
   
   {"PopupContextMenu", NULL, N_("Popup context menu"), SHFT"F10",  N_("Popup context menu"), G_CALLBACK(act_popup_context_menu)},
@@ -2516,11 +2522,10 @@ kz_actions_set_sensitive (KzWindow *kz, KzEmbed *kzembed)
 
 
 GtkActionGroup *
-kz_actions_create_group (KzWindow *kz, GtkAccelGroup *accel_group)
+kz_actions_create_group (KzWindow *kz)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	GList *node, *action_list;
 
 	action_group = gtk_action_group_new("KzWindow");
 	gtk_action_group_set_translation_domain(action_group, NULL);
@@ -2587,16 +2592,6 @@ kz_actions_create_group (KzWindow *kz, GtkAccelGroup *accel_group)
 		g_object_unref(action);
 	}
 
-	action_list = gtk_action_group_list_actions(action_group);
-	
-	for (node = action_list; node; node = g_list_next(node))
-	{
-		gtk_action_set_accel_group(GTK_ACTION(node->data),
-					   accel_group);
-		gtk_action_connect_accelerator(GTK_ACTION(node->data));
-	}
-	g_list_free(action_list);
-
 	return action_group;
 }
 
