@@ -479,6 +479,20 @@ kz_embed_get_links (KzEmbed *kzembed,
 }
 
 
+gboolean
+kz_embed_get_dest_anchors (KzEmbed *kzembed,
+			   GList **list)
+{
+	g_return_val_if_fail(list, FALSE);
+	*list = NULL;
+	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
+	g_return_val_if_fail(KZ_EMBED_GET_IFACE(kzembed)->get_links, FALSE);
+
+	return KZ_EMBED_GET_IFACE(kzembed)->get_dest_anchors(kzembed,
+							     list);
+}
+
+
 void
 kz_embed_copy_page (KzEmbed *kzembed, KzEmbed *dkzembed)
 {
