@@ -42,15 +42,18 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #include "kz-window.h"
 #include "kz-actions-tab.h"
 #include "kz-xbel.h"
+#include "kz-ext.h"
 #include "locale.h"
 #include "utils.h"
-#include "estsearch.h"
-#include "mozilla.h"
-#if (GLIB_MAJOR_VERSION == 2) && ((GLIB_MINOR_VERSION < 5) || \
-		((GLIB_MINOR_VERSION >= 5) && (GLIB_MICRO_VERSION < 4)))
-#include "goption.h"
+
+#if USE_HYPERESTRAIER
+#	include "estsearch.h"
+#elif USE_RAST
+#	include "rast-search.h"
 #endif
 
+#include "mozilla.h"
+
 KzProfile      *kz_global_profile = NULL;
 KzProfile      *kz_proxy          = NULL;
 KzRootBookmark *kz_bookmarks      = NULL;
@@ -76,8 +79,7 @@ static GOptionGroup *main_group;
 
 gboolean is_restoring_session = FALSE;
 
-gboolean exists_estindex = FALSE;
-gchar   *estversion;
+gboolean exists_search_cmd = FALSE;
 
 static void activate_action(const gchar *text);
 
@@ -327,7 +329,7 @@ activate_action(const gchar *text)
 
 	window_list = kz_window_get_window_list();
 	
-	if (!strncmp(text, "KzWindowTabPopup", 16))
+	if (g_str_has_prefix(text, "KzWindowTabPopup"))
 	{
 		gchar *p1, *p2, *p3;
 		action_type = TAB_ACTION;
@@ -350,7 +352,7 @@ activate_action(const gchar *text)
 		}
 		tab_id = !tab_id ? -1 : tab_id;
 	}
-	else /*if (!strncmp(action, "KzWindow", 8))*/
+	else /*if (g_str_has_prefix(action, "KzWindow"))*/
 	{
 		gchar *p1, *p2;
 		action_type = WINDOW_ACTION;
@@ -513,32 +515,19 @@ clean_history_cache (void)
 	KZ_CONF_GET("History", "limit_cache", limit, BOOL);
 	if (limit)
 	{
-		GSList *purge_list = NULL;
-		gchar **purge_files = NULL;
-
 		limit_seconds = limit_days * 86400;
-		history_dir = g_build_filename(g_get_home_dir(),
-					       HISTORY_DIR,
-					       NULL); 
-		purge_list = purge_history_file(history_dir, limit_seconds);
+		history_dir = g_strconcat(g_get_home_dir(),
+					  HISTORY_DIR,
+					  NULL); 
+		purge_history_file(history_dir, limit_seconds);
 		g_free(history_dir);
 
-		if (purge_list)
+		if (exists_search_cmd)
 		{
-			GSList *slist;
-			gint n = g_slist_length(purge_list);
-			purge_files = g_new0 (gchar*, n + 1);
-
-			purge_files[n--] = NULL;
-			for (slist = purge_list; slist; slist = slist->next)
-				purge_files[n--] = slist->data;
-
-			/* optimize and purge history index */
-			if (exists_estindex)
-				estsearch_purge_index(purge_files);
-		 
-			g_strfreev(purge_files);
-			g_slist_free(purge_list);
+#if USE_HYPERESTRAIER
+			estsearch_purge_index();
+#elif USE_RAST
+#endif
 		}
 	}
 }
@@ -577,7 +566,8 @@ open_app_info (void)
 	gchar *smartbookmark_file, *sys_smartbookmark_file;
 	gchar *accel_prefs_file;
 	gchar *proxy_file, *sysproxy_file;
-	gchar *estindex;
+	gchar *search_command;
+	gboolean exists_index, use_history_search = FALSE;
 
 	/* load prefs */
 	sysconf_file = g_strdup(KZ_SYSCONFDIR "/kzrc");
@@ -587,6 +577,30 @@ open_app_info (void)
 	
 	kz_global_profile = kz_profile_open(conf_file, sysconf_file);
 
+	/* check HyperEstraier Index */
+	KZ_CONF_GET("History", "store_cache", use_history_search, BOOL);
+	if (use_history_search)
+	{
+#if USE_HYPERESTRAIER
+		search_command = g_find_program_in_path("estcmd");
+		exists_index = estsearch_exist_index_dir();
+#elif USE_RAST
+		search_command = g_find_program_in_path("rast");
+		exists_index = rast_exist_index_dir();
+#endif
+		if (search_command)
+		{
+			exists_search_cmd = TRUE;
+			if (!exists_index)
+#if USE_HYPERESTRAIER
+				estsearch_make_index();
+#elif USE_RAST
+				rast_make_index();
+#endif
+			g_free(search_command);
+		}
+	}
+
 	/* load bookmarks */
 	bookmark_file         = g_build_filename(g_get_home_dir(),
 					    	 "."PACKAGE,
@@ -653,16 +667,7 @@ open_app_info (void)
 	gnutls_global_init ();
 #endif
 
-	/* check existence of estindex */
-	estindex = g_find_program_in_path("estindex");
-	
-	if (estindex)
-	{
-		exists_estindex = TRUE;
-		g_free(estindex);
-		/* check estraier version */
-		estversion = estsearch_get_version();
-	}
+	kz_ext_init();
 
 	/* make dirs */
 	prepare_dir();
@@ -688,6 +693,8 @@ close_app_info (void)
 {
 	gchar *accel_prefs_file;
 
+	kz_ext_exit();
+
 	accel_prefs_file = g_build_filename (g_get_home_dir(),
 					     "."PACKAGE,
 					     "keyaccelrc",
@@ -707,12 +714,6 @@ close_app_info (void)
 	kz_profile_close(kz_global_profile);
 	kz_profile_close(kz_proxy);
 
-	if (estversion)
-	{
-		g_free(estversion);
-		estversion = NULL;
-	}
-	
 #if USE_MIGEMO
 	if (migemo)
 	{
