@@ -41,7 +41,12 @@
 #include "migemo.h"
 #endif
 #include "utils.h"
-#include "estsearch.h"
+
+#if USE_HYPERESTRAIER
+#	include "estsearch.h"
+#elif USE_RAST
+#	include "rast-search.h"
+#endif
 
 #include <nsCOMPtr.h>
 #include <nsIDOMDocument.h>
@@ -197,6 +202,9 @@ static gboolean     kz_moz_embed_get_links             (KzEmbed      *kzembed,
 							GList       **list,
 							gboolean      selected_only);
 
+static gboolean     kz_moz_embed_get_dest_anchors      (KzEmbed      *kzembed,
+							GList       **list);
+
 static void         kz_moz_embed_copy_page             (KzEmbed      *kzembed,
 							KzEmbed      *dkzembed);
 static gboolean     kz_moz_embed_shistory_copy         (KzEmbed      *source,
@@ -214,7 +222,7 @@ static void         kz_moz_embed_shistory_get_nth      (KzEmbed      *kzembed,
 							char        **aTitle);
 
 static void         kz_moz_embed_reload                (KzEmbed      *kzembed,
-							gint32        flags);
+							KzEmbedReloadFlag flags);
 static void         kz_moz_embed_stop_load             (KzEmbed      *kzembed);
 static void         kz_moz_embed_go_back               (KzEmbed      *kzembed);
 static void         kz_moz_embed_go_forward            (KzEmbed      *kzembed);
@@ -310,6 +318,7 @@ static void	     kz_moz_embed_set_allow_javascript	(KzEmbed      *kzembed,
 static gboolean	     kz_moz_embed_get_allow_images	(KzEmbed      *kzembed);
 static void	     kz_moz_embed_set_allow_images	(KzEmbed      *kzembed,
     							 gboolean      allow);
+static void          kz_moz_embed_show_page_certificate (KzEmbed       *kzembed);
 
 static GtkMozEmbedClass *parent_class = NULL;
 
@@ -336,6 +345,7 @@ kz_moz_embed_iface_init (KzEmbedIFace *iface)
 	iface->incremental_search     = kz_moz_embed_incremental_search;
 	iface->selection_is_collapsed = kz_moz_embed_selection_is_collapsed;
 	iface->get_links              = kz_moz_embed_get_links;
+	iface->get_dest_anchors       = kz_moz_embed_get_dest_anchors;
 	iface->copy_page              = kz_moz_embed_copy_page;
 	iface->shistory_copy          = kz_moz_embed_shistory_copy;
 	iface->shistory_get_pos       = kz_moz_embed_shistory_get_pos;
@@ -387,6 +397,9 @@ kz_moz_embed_iface_init (KzEmbedIFace *iface)
 	iface->set_allow_javascript   = kz_moz_embed_set_allow_javascript;
 	iface->get_allow_images       = kz_moz_embed_get_allow_images;
 	iface->set_allow_images       = kz_moz_embed_set_allow_images;
+	iface->show_page_certificate  = kz_moz_embed_show_page_certificate;
+
+
 #if 0
 	iface->set_edit_mode          = set_edit_mode;
 	iface->set_view_mode          = set_view_mode;
@@ -510,7 +523,9 @@ kz_moz_embed_init (KzMozEmbed *kzembed)
 #endif
 	priv->last_highlight = NULL;
 	priv->first_url      = NULL;
+#ifndef HAVE_GECKO_1_8
 	kz_moz_embed_load_url(KZ_EMBED(kzembed), "about:blank");
+#endif
 }
 
 GtkWidget *
@@ -531,7 +546,9 @@ kz_moz_embed_new (const gchar *url)
 	// After "about:balnk" was loaded, the first url start to load.  
 	if (url)
 		priv->first_url = g_strdup(url);
-	//kz_moz_embed_load_url(KZ_EMBED(kzembed), url);
+#ifdef HAVE_GECKO_1_8
+	kz_moz_embed_load_url(KZ_EMBED(kzembed), url);
+#endif
 
 	return GTK_WIDGET(kzembed);
 }
@@ -700,8 +717,9 @@ kz_moz_embed_load_url (KzEmbed *kzembed, const gchar *url)
 		return;
 	}
 	else
+	{
 		gtk_moz_embed_load_url(GTK_MOZ_EMBED(kzembed), start_page);
-	
+	}
 	if (mozembed->location)
 		g_free(mozembed->location);
 	mozembed->location = start_page;
@@ -952,6 +970,8 @@ net_stop_proccess (KzMozEmbed *kzembed)
 {
 	KzMozEmbedPrivate *priv = KZ_MOZ_EMBED_GET_PRIVATE (kzembed);
 
+	if (!priv->wrapper) return;
+	
 	gboolean create_thumbnail = FALSE, store_cache = TRUE;
 	KZ_CONF_GET("Global", "create_thumbnail", create_thumbnail, BOOL);
 	KZ_CONF_GET("History", "store_cache", store_cache, BOOL);
@@ -995,14 +1015,18 @@ net_stop_proccess (KzMozEmbed *kzembed)
 			kz_moz_embed_create_thumbnail(KZ_EMBED(kzembed));
 		}
 		
-		if (store_cache && exists_estindex &&
+		if (store_cache && exists_search_cmd &&
 		    (!last_modified || (history_get_last_modified(uri) < last_modified)) &&
 		    !g_str_has_prefix(location, "history-search:"))
 		{
 			gchar *filename;
 			filename = mozilla_store_history_file(kzembed);
 			if (filename)
+#if USE_HYPERESTRAIER
 				g_idle_add(estsearch_update_index, filename);
+#elif USE_RAST
+				g_idle_add(rast_update_index, filename);
+#endif
 		}
 	}
 	
@@ -1901,6 +1925,32 @@ kz_moz_embed_get_links (KzEmbed *kzembed, GList **list,
 }
 
 
+static gboolean
+kz_moz_embed_get_dest_anchors (KzEmbed *kzembed, GList **list)
+{
+	g_return_val_if_fail(KZ_IS_MOZ_EMBED(kzembed), FALSE);
+	KzMozEmbed *mozembed = KZ_MOZ_EMBED(kzembed);
+	KzMozEmbedPrivate *priv = KZ_MOZ_EMBED_GET_PRIVATE (kzembed);
+	g_return_val_if_fail(priv->wrapper, FALSE);
+	g_return_val_if_fail(list, FALSE);
+
+	// get all anchor nodes in the document.
+	nsCOMPtr<nsIDOMDocument> mainDoc;
+        nsresult rv = priv->wrapper->GetMainDomDocument(getter_AddRefs(mainDoc));
+        if (NS_FAILED(rv) || !mainDoc) return FALSE;
+
+        // get main DOMWindow
+	nsCOMPtr<nsIDOMWindow> mainDOMWindow;
+	rv = priv->wrapper->GetDOMWindow(getter_AddRefs(mainDOMWindow));
+	if (NS_FAILED(rv)) return FALSE;
+
+	rv = priv->wrapper->GetDestAnchorsFromWindow(mainDOMWindow,
+						     list);
+
+	return NS_FAILED(rv) ? FALSE : TRUE;
+}
+
+
 glong
 kz_moz_embed_get_key_event_info(KzMozEmbed *kzembed, gpointer event,
 				KzEmbedEventKey **info_ret)
@@ -1920,10 +1970,10 @@ kz_moz_embed_get_key_event_info(KzMozEmbed *kzembed, gpointer event,
 
 	PRUint32 code;
 	aKeyEvent->GetKeyCode(&code);
-	code = info->key;
+	info->key = code;
 
 	aKeyEvent->GetCharCode(&code);
-	code = info->char_code;
+	info->char_code = code;
 
 	PRBool mod_key;
 	info->modifier = 0;
@@ -2229,10 +2279,30 @@ kz_moz_embed_get_up_location(KzMozEmbed *kzembed)
 }
 
 static void
-kz_moz_embed_reload (KzEmbed *kzembed, gint32 flags)
+kz_moz_embed_reload (KzEmbed *kzembed, KzEmbedReloadFlag flags)
 {
+	gint32 moz_flags;
 	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
-	gtk_moz_embed_reload(GTK_MOZ_EMBED(kzembed), flags);
+
+	switch (flags) {
+	  case KZ_EMBED_RELOAD_NORMAL:
+	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
+	    break;
+	  case KZ_EMBED_RELOAD_BYPASS_CACHE:
+	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSCACHE;
+	    break;
+	  case KZ_EMBED_RELOAD_BYPASS_PROXY:
+	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSPROXY;
+	    break;
+	  case KZ_EMBED_RELOAD_BYPASS_PROXY_AND_CACHE:
+	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSPROXYANDCACHE;
+	    break;
+	  case KZ_EMBED_RELOAD_CHARSET_CHANGE:
+	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADCHARSETCHANGE;
+	    break;
+	}
+
+	gtk_moz_embed_reload(GTK_MOZ_EMBED(kzembed), moz_flags);
 }
 
 
@@ -3221,3 +3291,17 @@ kz_moz_embed_set_allow_images (KzEmbed *kzembed, gboolean allow)
 	priv->wrapper->SetAllowImages(allow);
 }
 
+static void
+kz_moz_embed_show_page_certificate (KzEmbed       *kzembed)
+{
+	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
+
+	KzMozEmbedPrivate *priv = KZ_MOZ_EMBED_GET_PRIVATE (kzembed);
+
+	if (!priv->wrapper) return;
+
+	priv->wrapper->ShowPageCertificate();
+
+}
+
+
