@@ -50,10 +50,10 @@ typedef struct _KzPrefsGeneral
 	GtkWidget     *main_vbox;
 	GtkWidget     *user_agent_frame;
 	GtkWidget     *user_agent_vbox;
+	GtkWidget     *copy_format_frame;
+	GtkWidget     *copy_format_vbox;
 	GtkWidget     *override_check;
 	GtkWidget     *user_agent_entry;
-	GtkWidget     *bookmark_menu_frame;
-	GtkWidget     *bookmark_menu_vbox;
 	GtkWidget     *create_thumbnail;
 	GtkWidget     *popup_thumbnail;
 	GtkWidget     *save_check;
@@ -96,6 +96,22 @@ cb_user_agent_toggled(GtkToggleButton *button, KzPrefsGeneral *prefsui)
 	prefsui->changed = TRUE;
 }
 
+static void
+cb_copy_format_button_clicked (GtkWidget *widget, KzPrefsGeneral *prefsui)
+{
+	GtkWidget *top;
+	KzWindow *kz;
+	GtkAction *action;
+
+	top = gtk_widget_get_toplevel(prefsui->main_vbox);
+	if (!GTK_IS_WINDOW(top)) return;
+
+	kz = KZ_WINDOW(gtk_window_get_transient_for(GTK_WINDOW(top)));
+	if (!KZ_IS_WINDOW(kz)) return;
+
+	action = gtk_action_group_get_action(kz->actions, "ShowCopyFormat");
+	gtk_action_activate(action);
+}
 
 static void
 cb_changed (GtkWidget *widget, KzPrefsGeneral *prefsui)
@@ -109,7 +125,7 @@ prefs_general_create (void)
 {
 	KzPrefsGeneral *prefsui = g_new0(KzPrefsGeneral, 1);
 	GtkWidget *main_vbox, *vbox, *hbox, *frame;
-	GtkWidget *label, *entry;
+	GtkWidget *label, *entry, *button;
 	GtkWidget *option_menu, *check;
 	gchar *value;
 	gboolean thumbnail = FALSE, popup_thumbnail = FALSE;
@@ -171,73 +187,34 @@ prefs_general_create (void)
 	if (value)
 		gtk_entry_set_text(GTK_ENTRY(entry), value);
 	g_free(value);
-#if 0
+
 	/*
 	 * Copy Format
 	 */
-	frame = gtk_frame_new(_("Copy Format"));
+	frame = gtk_frame_new(_("Define Copy Format"));
+	prefsui->copy_format_frame = frame;
 	gtk_frame_set_label_align(GTK_FRAME(frame), 0.03, 0.5);
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(main_vbox), frame, FALSE, FALSE, 2);
 	gtk_widget_show(frame);
 
 	vbox = gtk_vbox_new(FALSE, 0);
-	prefsui->user_agent_vbox = vbox;
+	prefsui->copy_format_vbox = vbox;
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_widget_show(vbox);
 
-	label = gtk_label_new(_("You can specify the format of copied title, URI, Selected text. "
-				"%t% -> Title %u% -> URI %s% -> Selected text(in case right-click document only)"));
-	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-	gtk_box_pack_start(GTK_BOX(vbox), label,
-			   FALSE, FALSE, 10);
-	gtk_widget_show(label);
-
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new_with_mnemonic(_("Copy Format in case right-click document : "));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-	gtk_widget_show(label);
+	button = gtk_button_new_with_mnemonic(_("Define Copy Format..."));
+	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	g_signal_connect(button, "clicked",
+			 G_CALLBACK(cb_copy_format_button_clicked), prefsui);
+	gtk_widget_show(button);
 
-	entry = gtk_entry_new();
-	prefsui->copy_document_format= entry;
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 2);
-	gtk_widget_show(entry);
-
-	value = KZ_CONF_GET_STR("Global", "copy_document_format1");
-	if (value)
-	{
-		gtk_entry_set_text(GTK_ENTRY(entry), value);
-		g_free(value);
-	}
-
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
-	label = gtk_label_new_with_mnemonic(_("Copy Format in case right-click tab: "));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-	gtk_widget_show(label);
-
-	entry = gtk_entry_new();
-	prefsui->copy_tab_format = entry;
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 2);
-	gtk_widget_show(entry);
-
-	value = KZ_CONF_GET_STR("Global", "copy_tab_format1");
-	if (value)
-	{
-		gtk_entry_set_text(GTK_ENTRY(entry), value);
-		g_free(value);
-	}
-#endif
 	/*
 	 *  Thumbnail 
 	 */
@@ -426,9 +403,9 @@ prefs_general_response (GtkWidget *widget, gint response)
 		/* User-Agent */
 		gtk_widget_hide(prefsui->user_agent_frame);
 		gtk_widget_hide(prefsui->user_agent_vbox);
-		/* Bookmark menu */
-		gtk_widget_hide(prefsui->bookmark_menu_frame);
-		gtk_widget_hide(prefsui->bookmark_menu_vbox);
+		/* Copy format */
+		gtk_widget_hide(prefsui->copy_format_frame);
+		gtk_widget_hide(prefsui->copy_format_vbox);
 		break;
 	}
 	case KZ_RESPONSE_UI_LEVEL_MEDIUM:
@@ -442,9 +419,9 @@ prefs_general_response (GtkWidget *widget, gint response)
 		/* User-Agent */
 		gtk_widget_hide(prefsui->user_agent_frame);
 		gtk_widget_hide(prefsui->user_agent_vbox);
-		/* Bookmark menu */
-		gtk_widget_hide(prefsui->bookmark_menu_frame);
-		gtk_widget_hide(prefsui->bookmark_menu_vbox);
+		/* Copy format */
+		gtk_widget_hide(prefsui->copy_format_frame);
+		gtk_widget_hide(prefsui->copy_format_vbox);
 		break;
 	}
 	case KZ_RESPONSE_UI_LEVEL_EXPERT:
@@ -458,6 +435,9 @@ prefs_general_response (GtkWidget *widget, gint response)
 		/* User-Agent */
 		gtk_widget_show(prefsui->user_agent_frame);
 		gtk_widget_show(prefsui->user_agent_vbox);
+		/* Copy format */
+		gtk_widget_show(prefsui->copy_format_frame);
+		gtk_widget_show(prefsui->copy_format_vbox);
 		break;
 	}
 	case KZ_RESPONSE_UI_LEVEL_CUSTOM:
